from rfcnt.tests import examples


def main():
    print("Running example 1...")
    examples.example_1()


if __name__ == '__main__':
    main()


"""
Jupyter Notebook:
!pip install ./rfcnt-0.4.0.tar.gz
!pip install --upgrade matplotlib
!python -m rfcnt.run_examples
"""
